/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IResourceMonitor.java 4392 2008-12-15 14:05:41Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.plan.monitor.api;

import java.util.List;

import org.ow2.util.plan.bindings.deploymentplan.DeploymentPlanFragment;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;

/**
 * Interface for the resource monitor.
 * @author Mickaël LEDUQUE
 */
public interface IResourceMonitor {

    /**
     * Adds a resource to be monitored.
     * @param resourceFetcher the fetcher for the monitored resource.
     */
    void addMonitoredResource(IResourceFetcher resourceFetcher);

    /**
     * Removes a monitored resource.
     * @param deployment the removed resource.
     */
    void removeMonitoredResource(DeploymentPlanFragment deployment);

    /**
     * Removes a monitored resource by its resource fetcher.
     * @param resourceFetcher the fetcher for the removed resource.
     */
    void removeMonitoredResource(IResourceFetcher resourceFetcher);

    /**
     * Checks if some resources has changed. Return the changed ones.
     * @return the list of resources that changed.
     */
    List<IResourceFetcher> getChangedResources();

    /**
     * Returns the number of monitored resources.
     * @return the number of monitored resources.
     */
    Integer getMonitoredResourcesCount();

    /**
     * Gives the descriptions of the monitored resources.
     * @return the descriptions of the monitored resources.
     */
    List<String> getMonitoredResourcesDescriptions();
}
